@@ -1,6 +1,8 @@
 import os
 import click
 
+from .core import DelimitedStr
+
 @click.command(name='build_xml_ws')
 @click.option('-i', '--filename', 'source', required=True, 
               help='Input xml file.')
@@ -94,4 +96,63 @@ def modify_ws(**kwargs):
     _kwargs['minimizer_config'] = kwargs
     from quickstats.components.workspaces import XMLWSModifier
     modifier = XMLWSModifier(**_kwargs)
-    modifier.create_modified_workspace()
\ No newline at end of file
+    modifier.create_modified_workspace()
+    
+kItemChoices = ['workspace', 'dataset', 'category', 'snapshot', 'pdf',
+                'function', 'poi', 'nuisance_parameter', 'global_observables',
+                'constrained_nuisance_parameter', 'unconstrained_nuisance_parameter',
+                'auxiliary']
+kDefaultItems = ",".join(['workspace', 'dataset', 'category', 'poi', 'pdf',
+                          'function', 'nuisance_parameter', 'global_observable',
+                          'auxiliary'])
+kDefaultVisibility = ",".join(["workspace=0b11001", "category=0b10011", "snapshot=0b10011",
+                               "dataset=0b11011", "pdf=0b01011", "function=0b01011" , "poi=0b01011",
+                               "nuisance_parameter=0b01011", "global_observable=0b01011", "auxiliary=0b01011"])
+
+@click.command(name='compare_ws')
+@click.option('-l', '--left', required=True, 
+              help='Path to the input workspace file (left of comparison).')
+@click.option('-r', '--right', required=True, 
+              help='Path to the input workspace file (right of comparison).')
+@click.option('--items', cls=DelimitedStr, type=click.Choice(kItemChoices),
+              default=kDefaultItems, show_default=True,
+              help='Items to include in the comparison (seperated by commas).')
+@click.option('--indent', default="   ", show_default=True,
+              help='Indentation for each row.')
+@click.option('--visibility', default=kDefaultVisibility, show_default=True,
+              help='\b\n Set visibility of the items included in the comparison:'
+                   '\b\n boolean mask for showing definitions of certain objects'
+                   '\b\n 0b00001 = show definitions for unique objects'
+                   '\b\n 0b00010 = show definitions for redefined objects'
+                   '\b\n 0b00100 = show definitions for reconstituted objects'
+                   '\b\n 0b01000 = show definitions for renamed/remapped objects'
+                   '\b\n 0b10000 = show definitions for identical objects')
+@click.option('--save_text', default=None,
+              help='Save summary print out as a text file.')
+@click.option('--save_json_data', default=None,
+              help='Save comparison data as a json file.')
+@click.option('--save_excel_data', default=None,
+              help='Save comparison data as an excel file.')
+@click.option('-v', '--verbosity',  default="INFO", show_default=True,
+              help='verbosity level ("DEBUG", "INFO", "WARNING", "ERROR")')
+def compare_ws(**kwargs):
+    """
+    Compare two workspace files
+    """
+    from quickstats.components.workspaces import WSComparer
+    comparer = WSComparer(kwargs["left"], kwargs["right"], items=kwargs["items"],
+                          visibility_map=kwargs["visibility"])
+    comparer.load_data()
+    comparer.process_data()
+    summary_str = comparer.get_summary_str(indent=kwargs["indent"])
+    print(summary_str)
+    save_text = kwargs["save_text"]
+    save_json_data = kwargs["save_json_data"]
+    save_excel_data = kwargs["save_excel_data"]
+    if save_text is not None:
+        with open(save_text, "w") as f:
+            f.write(summary_str)
+    if save_json_data is not None:
+        comparer.save_json(save_json_data)
+    if save_excel_data is not None:
+        comparer.save_excel(save_excel_data)
\ No newline at end of file
