@@ -8,6 +8,10 @@ class AbstractObject(object):
     
     stdout = quickstats._PRINT_
     
+    @property
+    def debug_mode(self):
+        return self.stdout._verbosity._name_ == "DEBUG"
+    
     def __init__(self, verbosity:Optional[Union[int, str]]=None):
         
         if verbosity is None:
