@@ -1114,8 +1114,12 @@ class ExtendedModel(AbstractObject):
         return toys
     
     def save(self, fname:str, recreate:bool=True):
+        """
+        # buggy, model config is messed up
         new_ws = ROOT.RooWorkspace(self.workspace)
         new_ws.writeToFile(fname, recreate)
+        """
+        self.workspace.writeToFile(fname, recreate)
     
     @semistaticmethod
     def load_ws(self, fname:str, ws_name:Optional[str]=None, mc_name:Optional[str]=None):
