@@ -17,7 +17,7 @@ from quickstats.utils.io import Verbosity, get_colored_text, format_comparison_t
 from quickstats.utils.root_utils import load_macro, get_macro_dir
 from quickstats.maths.numerics import is_float, pretty_value
 from quickstats.components.basics import WSVariables
-from quickstats.utils.general_enum import GeneralEnum
+from quickstats.utils.enums import GeneralEnum
 from quickstats.interface.root.roofit_extension import get_str_data
 
 kUnique        = 0b00001
