@@ -12,7 +12,7 @@ from quickstats import semistaticmethod
 from quickstats.components import AbstractObject
 from quickstats.utils.io import Verbosity
 from quickstats.utils.xml_tools import TXMLTree
-from quickstats.utils.general_enum import GeneralEnum
+from quickstats.utils.enums import GeneralEnum
 from quickstats.maths.numerics import to_bool
 from quickstats.utils.root_utils import load_macro,get_macro_TClass
 
