@@ -22,7 +22,7 @@ from quickstats.maths.numerics import is_float, pretty_value
 from quickstats.components.basics import WSVariables
 from quickstats.components.workspaces import XMLWSBase, WSObjectType, AsimovHandler
 
-from quickstats.utils.general_enum import GeneralEnum
+from quickstats.utils.enums import GeneralEnum
 
 class ModifierAction(GeneralEnum):
     NORMAL     = 0
