@@ -13,4 +13,7 @@ from quickstats.interface.root.RooMsgService import RooMsgService
 
 from quickstats.interface.root.data_conversion import *
 
-load_macros()
\ No newline at end of file
+load_macros()
+
+import quickstats
+quickstats.load_corelib()
\ No newline at end of file
