@@ -184,7 +184,9 @@ def print_object(obj, indent=0, spacer="  ", prefix="-", show_address=False):
     else:
         print(f"{spacer*indent}{prefix}{obj.GetName()}({obj.ClassName()})")
         
-def print_pdf_structure(pdf:"ROOT.RooAbsPdf", level:int=0, show_address=False):
+def print_pdf_structure(pdf:"ROOT.RooAbsPdf", level:int=0, show_address=False, max_level:int=-1):
+    if (max_level >= 0) and (level > max_level):
+        return None
     print_object(pdf, level, show_address=show_address)
     class_name = pdf.ClassName()
     if class_name == "RooSimultaneous":
@@ -193,17 +195,17 @@ def print_pdf_structure(pdf:"ROOT.RooAbsPdf", level:int=0, show_address=False):
         for i in range(n_bins):
             cat.setBin(i)
             pdf_i = pdf.getPdf(cat.getLabel())
-            print_pdf_structure(pdf_i, level+1, show_address=show_address)
+            print_pdf_structure(pdf_i, level+1, show_address=show_address, max_level=max_level)
     elif class_name == "RooProdPdf":
         pdf_list = pdf.pdfList()
         for pdf_i in pdf_list:
-            print_pdf_structure(pdf_i, level+1, show_address=show_address)
+            print_pdf_structure(pdf_i, level+1, show_address=show_address, max_level=max_level)
     elif class_name == "RooRealSumPdf":
         pdf_list = pdf.getComponents()
         for pdf_i in pdf_list:
             if pdf_i == pdf:
                 continue
-            print_pdf_structure(pdf_i, level+1, show_address=show_address)
+            print_pdf_structure(pdf_i, level+1, show_address=show_address, max_level=max_level)
                      
 def get_correlation_matrix(roofit_result, lib:str="pandas"):
     correlation_hist = roofit_result.correlationHist()
